package server
import "github.com/theupdateframework/notary/server"
Index ¶
- func CreateHandler(operationName string, serverHandler utils.ContextHandler, errorIfGUNInvalid error, includeCacheHeaders bool, cacheControlConfig utils.CacheControlConfig, permissionsRequired []string, authWrapper utils.AuthWrapper, repoPrefixes []string) http.Handler
- func RootHandler(ctx context.Context, ac auth.AccessController, trust signed.CryptoService, consistent, current utils.CacheControlConfig, repoPrefixes []string) http.Handler
- func Run(ctx context.Context, conf Config) error
- type Config
Functions ¶
func CreateHandler ¶
func CreateHandler(operationName string, serverHandler utils.ContextHandler, errorIfGUNInvalid error, includeCacheHeaders bool, cacheControlConfig utils.CacheControlConfig, permissionsRequired []string, authWrapper utils.AuthWrapper, repoPrefixes []string) http.Handler
CreateHandler creates a server handler, wrapping with auth, caching, and monitoring
func RootHandler ¶
func RootHandler(ctx context.Context, ac auth.AccessController, trust signed.CryptoService, consistent, current utils.CacheControlConfig, repoPrefixes []string) http.Handler
RootHandler returns the handler that routes all the paths from / for the server.
func Run ¶
Run sets up and starts a TLS server that can be cancelled using the given configuration. The context it is passed is the context it should use directly for the TLS server, and generate children off for requests
Types ¶
type Config ¶
type Config struct {
Addr string
TLSConfig *tls.Config
Trust signed.CryptoService
AuthMethod string
AuthOpts interface{}
RepoPrefixes []string
ConsistentCacheControlConfig utils.CacheControlConfig
CurrentCacheControlConfig utils.CacheControlConfig
}
Config tells Run how to configure a server
Source Files ¶
Directories ¶
| Path | Synopsis |
|---|---|
| server/errors | |
| server/handlers | |
| server/snapshot | |
| server/storage | |
| server/timestamp |
- Version
- v0.7.0 (latest)
- Published
- Jan 14, 2021
- Platform
- linux/amd64
- Imports
- 17 packages
- Last checked
- 8 months ago –
Tools for package owners.